kedro.io.Version — Kedro 0.17.6 documentation

# kedro.io.Version

class `kedro.io.` `Version`(load, save)

  This namedtuple is used to provide load and save versions for versioned data sets. If `Version.load` is None, then the latest available version is loaded. If `Version.save` is None, then save version is formatted as YYYY-MM-DDThh.mm.ss.sssZ of the current timestamp.

  Attributes

  `load` | Alias for field number 0
  `save` | Alias for field number 1

  Methods

  `count`(value) |
  `index`(value, [start, [stop]]) | Raises ValueError if the value is not present.

  `count`(value) → integer – return number of occurrences of value
  `index`(value[, start[, stop]]) → integer – return first index of value.

    Raises ValueError if the value is not present.

  property `load`

    Alias for field number 0

  property `save`

    Alias for field number 1